| Title: | Simple 'htmlwidgets' Image Viewer with WebGL Brightness/Contrast |
|---|---|
| Description: | Display a 2D-matrix data as a interactive zoomable gray-scale image viewer, providing tools for manual data inspection. The viewer window shows cursor guiding lines and a corresponding data slices for both axes at the current cursor position. A tool-bar allows adjusting image display brightness/contrast through WebGL filters and performing basic high-pass/low-pass filtering. |
| Authors: | Iakov Pustilnik [aut, cre], Denis Rastegaev [aut] |
| Maintainer: | Iakov Pustilnik <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-28 10:13:57 UTC |
| Source: | https://github.com/yapus/imageviewer |
Simple htmlwidgets matrix viewer with WebGL brightness/contrast
imageviewer(data, width = NULL, height = NULL, elementId = NULL, options = list())imageviewer(data, width = NULL, height = NULL, elementId = NULL, options = list())
data |
A matrix |
width, height
|
matrix dimensions |
elementId |
HTML element Id |
options |
list of other options (passed through to JS code) |
Plot matrix in html widget
# Create matrix m <- matrix(rnorm(512 * 512, mean = 100, sd = 10), 512, 512) # Plot imageviewer(m)# Create matrix m <- matrix(rnorm(512 * 512, mean = 100, sd = 10), 512, 512) # Plot imageviewer(m)
Output and render functions for using imageviewer within Shiny applications and interactive Rmd documents.
imageviewerOutput(outputId, width = "100%", height = "400px") renderImageviewer(expr, env = parent.frame(), quoted = FALSE)imageviewerOutput(outputId, width = "100%", height = "400px") renderImageviewer(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height
|
Must be a valid CSS unit (like |
expr |
An expression that generates a imageviewer |
env |
The environment in which to evaluate |
quoted |
Is |